PCB Environment: /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Util/Metrics.hpp Source File

PCB Environment 2

Loading...
Searching...
No Matches
Metrics.hpp
1
2#ifndef GYM_PCB_METRICS_H
3#define GYM_PCB_METRICS_H
4
5class Connection;
6class PCBoard;
7class WideSegment_25;
8
9namespace metrics {
10
11Real ConnectionLinkage(const Connection&, const Connection&, bool cross, Real ex = 2.0, int log2StepSize = -3);
12Real ConnectionLinkage(const PCBoard&, Real ex, int log2StepSize);
13uint RatsNestCrossings(const PCBoard&);
14
15void SegmentParallelity(Real &cosine, Real &weight, const WideSegment_25&, const WideSegment_25&);
16
17} // namespace metrics
18
19#endif // GYM_PCB_METRICS_H
Connection
Definition Connection.hpp:17
PCBoard
Definition PCBoard.hpp:36
WideSegment_25
Definition AShape.hpp:332